@@ -189,7 +189,7 @@ class hexagon_grid:
             df["geometry"] = df["geometry"].apply(lambda geom: geom.wkb)
             df = df.drop_duplicates(["geometry"])
             df["geometry"] = df["geometry"].apply(lambda geom: loads(geom))
-            pdf = gpd.overlay(self.data, df, how = 'union')
+            pdf = gpd.overlay(gdf, df, how = 'union')
             check_topology(pdf)
             self.geosolution = pdf
         elif 0.0 < self.area_threshold <= 0.8:
@@ -199,7 +199,7 @@ class hexagon_grid:
             df["geometry"] = df["geometry"].apply(lambda geom: geom.wkb)
             df = df.drop_duplicates(["geometry"])
             df["geometry"] = df["geometry"].apply(lambda geom: loads(geom))
-            pdf = gpd.overlay(self.data, df, how = 'union')
+            pdf = gpd.overlay(gdf, df, how = 'union')
             check_topology(pdf)
             self.geosolution = pdf
         else:
